@@ -27,6 +27,10 @@ class TeardownHooksFailure(MyBaseFailure):
     pass
 
 
+class NetworkFailure(MyBaseFailure):
+    pass
+
+
 """ error type exceptions
     these exceptions will mark test as error
 """
@@ -40,11 +44,11 @@ class FileFormatError(MyBaseError):
     pass
 
 
-class TestCaseFormatError(MyBaseError):
+class TestCaseFormatError(FileFormatError):
     pass
 
 
-class TestSuiteFormatError(MyBaseError):
+class TestSuiteFormatError(FileFormatError):
     pass
 
 
